==> regina-normal_4.6.orig.tar.gz: regina-4.6/kdeui/src/part/packettypes/nanglestructurecreator.h <==

/**************************************************************************
 *                                                                        *
 *  Regina - A Normal Surface Theory Calculator                           *
 *  KDE User Interface                                                    *
 *                                                                        *
 *  Copyright (c) 1999-2009, Ben Burton                                   *
 *  For further details contact Ben Burton (bab@debian.org).              *
 *                                                                        *
 *  This program is free software; you can redistribute it and/or         *
 *  modify it under the terms of the GNU General Public License as        *
 *  published by the Free Software Foundation; either version 2 of the    *
 *  License, or (at your option) any later version.                       *
 *                                                                        *
 *  This program is distributed in the hope that it will be useful, but   *
 *  WITHOUT ANY WARRANTY; without even the implied warranty of            *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *  General Public License for more details.                              *
 *                                                                        *
 *  You should have received a copy of the GNU General Public             *
 *  License along with this program; if not, write to the Free            *
 *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
 *  MA 02110-1301, USA.                                                   *
 *                                                                        *
 **************************************************************************/

/* end stub */

/*! \file nanglestructurecreator.h
 *  \brief Allows the creation of angle structure lists.
 */

#ifndef __NANGLESTRUCTURECREATOR_H
#define __NANGLESTRUCTURECREATOR_H

#include "../packetcreator.h"

/**
 * An interface for creating angle structure lists.
 */
class NAngleStructureCreator : public PacketCreator {
    public:
        /**
         * PacketCreator overrides.
         */
        regina::NPacket* createPacket(regina::NPacket* parentPacket,
            QWidget* parentWidget);
};

#endif

==> regina-normal_4.90.orig.tar.gz: regina-4.90/kdeui/src/part/packettypes/nanglestructurecreator.h <==

/**************************************************************************
 *                                                                        *
 *  Regina - A Normal Surface Theory Calculator                           *
 *  KDE User Interface                                                    *
 *                                                                        *
 *  Copyright (c) 1999-2011, Ben Burton                                   *
 *  For further details contact Ben Burton (bab@debian.org).              *
 *                                                                        *
 *  This program is free software; you can redistribute it and/or         *
 *  modify it under the terms of the GNU General Public License as        *
 *  published by the Free Software Foundation; either version 2 of the    *
 *  License, or (at your option) any later version.                       *
 *                                                                        *
 *  This program is distributed in the hope that it will be useful, but   *
 *  WITHOUT ANY WARRANTY; without even the implied warranty of            *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *  General Public License for more details.                              *
 *                                                                        *
 *  You should have received a copy of the GNU General Public             *
 *  License along with this program; if not, write to the Free            *
 *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
 *  MA 02110-1301, USA.                                                   *
 *                                                                        *
 **************************************************************************/

/* end stub */

/*! \file nanglestructurecreator.h
 *  \brief Allows the creation of angle structure lists.
 */

#ifndef __NANGLESTRUCTURECREATOR_H
#define __NANGLESTRUCTURECREATOR_H

#include "../packetcreator.h"

class QCheckBox;

/**
 * An interface for creating angle structure lists.
 */
class NAngleStructureCreator : public PacketCreator {
    private:
        /**
         * Internal components
         */
        QWidget* ui;
        QCheckBox* tautOnly;

    public:
        /**
         * Constructor.
         */
        NAngleStructureCreator();

        /**
         * PacketCreator overrides.
         */
        QWidget* getInterface();
        QString parentPrompt();
        QString parentWhatsThis();
        regina::NPacket* createPacket(regina::NPacket* parentPacket,
            QWidget* parentWidget);
};

#endif
